/*******************************************************************************
* File Name: Analog_in.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_Analog_in_H) /* Pins Analog_in_H */
#define CY_PINS_Analog_in_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "Analog_in_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    Analog_in_Write(uint8 value) ;
void    Analog_in_SetDriveMode(uint8 mode) ;
uint8   Analog_in_ReadDataReg(void) ;
uint8   Analog_in_Read(void) ;
void    Analog_in_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   Analog_in_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the Analog_in_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define Analog_in_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define Analog_in_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define Analog_in_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define Analog_in_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define Analog_in_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define Analog_in_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define Analog_in_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define Analog_in_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define Analog_in_MASK               Analog_in__MASK
#define Analog_in_SHIFT              Analog_in__SHIFT
#define Analog_in_WIDTH              1u

/* Interrupt constants */
#if defined(Analog_in__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in Analog_in_SetInterruptMode() function.
     *  @{
     */
        #define Analog_in_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define Analog_in_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define Analog_in_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define Analog_in_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define Analog_in_INTR_MASK      (0x01u)
#endif /* (Analog_in__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define Analog_in_PS                     (* (reg8 *) Analog_in__PS)
/* Data Register */
#define Analog_in_DR                     (* (reg8 *) Analog_in__DR)
/* Port Number */
#define Analog_in_PRT_NUM                (* (reg8 *) Analog_in__PRT) 
/* Connect to Analog Globals */                                                  
#define Analog_in_AG                     (* (reg8 *) Analog_in__AG)                       
/* Analog MUX bux enable */
#define Analog_in_AMUX                   (* (reg8 *) Analog_in__AMUX) 
/* Bidirectional Enable */                                                        
#define Analog_in_BIE                    (* (reg8 *) Analog_in__BIE)
/* Bit-mask for Aliased Register Access */
#define Analog_in_BIT_MASK               (* (reg8 *) Analog_in__BIT_MASK)
/* Bypass Enable */
#define Analog_in_BYP                    (* (reg8 *) Analog_in__BYP)
/* Port wide control signals */                                                   
#define Analog_in_CTL                    (* (reg8 *) Analog_in__CTL)
/* Drive Modes */
#define Analog_in_DM0                    (* (reg8 *) Analog_in__DM0) 
#define Analog_in_DM1                    (* (reg8 *) Analog_in__DM1)
#define Analog_in_DM2                    (* (reg8 *) Analog_in__DM2) 
/* Input Buffer Disable Override */
#define Analog_in_INP_DIS                (* (reg8 *) Analog_in__INP_DIS)
/* LCD Common or Segment Drive */
#define Analog_in_LCD_COM_SEG            (* (reg8 *) Analog_in__LCD_COM_SEG)
/* Enable Segment LCD */
#define Analog_in_LCD_EN                 (* (reg8 *) Analog_in__LCD_EN)
/* Slew Rate Control */
#define Analog_in_SLW                    (* (reg8 *) Analog_in__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define Analog_in_PRTDSI__CAPS_SEL       (* (reg8 *) Analog_in__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define Analog_in_PRTDSI__DBL_SYNC_IN    (* (reg8 *) Analog_in__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define Analog_in_PRTDSI__OE_SEL0        (* (reg8 *) Analog_in__PRTDSI__OE_SEL0) 
#define Analog_in_PRTDSI__OE_SEL1        (* (reg8 *) Analog_in__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define Analog_in_PRTDSI__OUT_SEL0       (* (reg8 *) Analog_in__PRTDSI__OUT_SEL0) 
#define Analog_in_PRTDSI__OUT_SEL1       (* (reg8 *) Analog_in__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define Analog_in_PRTDSI__SYNC_OUT       (* (reg8 *) Analog_in__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(Analog_in__SIO_CFG)
    #define Analog_in_SIO_HYST_EN        (* (reg8 *) Analog_in__SIO_HYST_EN)
    #define Analog_in_SIO_REG_HIFREQ     (* (reg8 *) Analog_in__SIO_REG_HIFREQ)
    #define Analog_in_SIO_CFG            (* (reg8 *) Analog_in__SIO_CFG)
    #define Analog_in_SIO_DIFF           (* (reg8 *) Analog_in__SIO_DIFF)
#endif /* (Analog_in__SIO_CFG) */

/* Interrupt Registers */
#if defined(Analog_in__INTSTAT)
    #define Analog_in_INTSTAT             (* (reg8 *) Analog_in__INTSTAT)
    #define Analog_in_SNAP                (* (reg8 *) Analog_in__SNAP)
    
	#define Analog_in_0_INTTYPE_REG 		(* (reg8 *) Analog_in__0__INTTYPE)
#endif /* (Analog_in__INTSTAT) */

#endif /* End Pins Analog_in_H */


/* [] END OF FILE */
